[**Iniziare**](./getting-started.md) > **Utilizzo** > **Riga di comando** _(current)_

---

### Utilizzare PDFMathTranslate tramite riga di comando

#### Utilizzo di base

Dopo l'Installazione, inserisci questo comando per tradurre il tuo PDF.

```bash
pdf2zh_next document.pdf
```

> [!NOTE]
> 
> Se il nome del percorso contiene spazi, si prega di racchiuderlo tra virgolette.
> 
> ```bash
> pdf2zh_next "path with spaces/document.pdf"
> ```

Dopo aver eseguito la traduzione, i file vengono generati nella **directory di lavoro corrente**.

> [!TIP]
> **Dov'è la mia "Directory di lavoro corrente"?**
> Prima di inserire un comando nel terminale, potresti vedere un percorso visualizzato nel tuo terminale:
> 
> ```powershell
> PS C:\Users\XXX>
> ```
> 
> Questa directory è la "*Directory di lavoro corrente*".
> 
> Se non c'è alcun percorso, prova a eseguire questo comando nel terminale:
> 
> ```bash
> pwd
> ```
> 
> Dopo aver eseguito questo comando, verrà visualizzato un percorso. Questo percorso è la "**Directory di lavoro corrente**". I file tradotti appariranno qui.

---

#### Opzioni avanzate

Per spiegazioni dettagliate sui parametri aggiuntivi della riga di comando, consultare [opzioni avanzate](./../advanced/advanced.md).

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>